<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\CategoryTasks;
use Illuminate\Http\Request;

class TaskController extends Controller
{
   public function index()
{
    $tasks = CategoryTasks::with('category')->orderBy('id', 'desc')->get();
    
    return view('admin.tasks.index', compact('tasks'));
}

    public function create()
    {
        $categories = Category::all();
        return view('admin.tasks.create', compact('categories'));
    }

    public function store(Request $request)
{
    $validated = $request->validate([
        'category_id' => 'required|exists:categories,id',
        'customer_name' => 'required|string|max:255',
        'city_name' => 'required|string|max:255',
        'address' => 'required|string',
        'landmark' => 'required|string',
        'pincode' => 'required|string',
        'village_ward_no' => 'required|string',
        'mobile_number' => 'required|string|max:15',
        'user_id' => 'required|exists:users,id', // Ensure user_id exists in users table
    ]);

    CategoryTasks::create($validated);

    return redirect()->route('admin.tasks.index')->with('success', 'Task created successfully.');
}

    public function edit($id)
{
    $task = CategoryTasks::findOrFail($id);
    $categories = Category::all();
    $users = \App\Models\User::all(); // Get all users to populate the select dropdown
    return view('admin.tasks.create', compact('task', 'categories', 'users'));
}


// app/Http/Controllers/Admin/TaskController.php

public function view($id)
{
    // Fetch the task with its category and user (if applicable)
    $task = CategoryTasks::with('category', 'user')->findOrFail($id);

    // Update the is_view status from 0 to 1
    $task->is_view = 1;
    $task->save(); // Save the updated task

    // Return the view with the task data
    return view('admin.tasks.view', compact('task'));
}



    public function update(Request $request, $id)
{
    $validated = $request->validate([
        'category_id' => 'required|exists:categories,id',
        'customer_name' => 'required|string|max:255',
        'city_name' => 'required|string|max:255',
        'address' => 'required|string',
        'landmark' => 'required|string',
        'pincode' => 'required|string',
        'village_ward_no' => 'required|string',
        'mobile_number' => 'required|string|max:15',
        'user_id' => 'required|exists:users,id', // Ensure user_id exists in users table
    ]);

    $task = CategoryTasks::findOrFail($id);
    $task->update($validated);

    return redirect()->route('admin.tasks.index')->with('success', 'Task updated successfully.');
}

    public function destroy($id)
    {
        $task = CategoryTasks::findOrFail($id);
        $task->delete();

        return redirect()->route('admin.tasks.index')->with('success', 'Task deleted successfully.');
    }
}
