<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\CategoryTasks;
use Illuminate\Http\Request;

class TaskController extends Controller
{
    public function index()
    {
        $tasks = Task::with('category')->get();
        return view('admin.tasks.index', compact('tasks'));
    }

    public function create()
    {
        $categories = Category::all();
        return view('admin.tasks.create', compact('categories'));
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'category_id' => 'required|exists:categories,id',
            'customer_name' => 'required|string|max:255',
            'city_name' => 'required|string|max:255',
            'address' => 'required|string',
            'mobile_number' => 'required|string|max:15',
        ]);

        Task::create($validated);

        return redirect()->route('tasks.index')->with('success', 'Task created successfully.');
    }

    public function edit($id)
    {
        $task = Task::findOrFail($id);
        $categories = Category::all();
        return view('admin.tasks.edit', compact('task', 'categories'));
    }

    public function update(Request $request, $id)
    {
        $validated = $request->validate([
            'category_id' => 'required|exists:categories,id',
            'customer_name' => 'required|string|max:255',
            'city_name' => 'required|string|max:255',
            'address' => 'required|string',
            'mobile_number' => 'required|string|max:15',
        ]);

        $task = Task::findOrFail($id);
        $task->update($validated);

        return redirect()->route('tasks.index')->with('success', 'Task updated successfully.');
    }

    public function destroy($id)
    {
        $task = Task::findOrFail($id);
        $task->delete();

        return redirect()->route('tasks.index')->with('success', 'Task deleted successfully.');
    }
}
