<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\CategoryTasks;
use Illuminate\Http\Request;

class TasksController extends Controller
{
    // Store a new task
    public function store(Request $request)
    {
        // Validate the request data
        $validated = $request->validate([
             'user_id' => 'required|exists:users,id',
            'category_id' => 'required|exists:categories,id',
            'customer_name' => 'required|string|max:255',
            'city_name' => 'required|string|max:255',
            'address' => 'required|string',
            'landmark' => 'required|string',
            'pincode' => 'nullable|string',
            'village_ward_no' => 'nullable|string',
            'mobile_number' => 'nullable|string|max:15',
        ]);

        // Create and store the task
        $task = CategoryTasks::create([
             'user_id' => $validated['user_id'],
        'category_id' => $validated['category_id'],
        'customer_name' => $validated['customer_name'],
        'city_name' => $validated['city_name'],
        'address' => $validated['address'],
            'landmark' => $validated['landmark'],
                'pincode' => $validated['pincode'],
                    'village_ward_no' => $validated['village_ward_no'],
                        'mobile_number' => $validated['mobile_number'],
    ]);
    
            $task->makeHidden(['created_at', 'updated_at']);

        // Return success response
    return response()->json([
        'status' => 200,
        'message' => 'Task created successfully.',
        'data' => $task,
    ], 200);
    }

    // Get task by ID
    public function show($id)
    {
        // Find the task by ID
        $task = CategoryTasks::with('category')->find($id);

        // Check if task exists
        if (!$task) {
            return response()->json(['message' => 'Task not found'], 404);
        }

        // Return the task data in JSON format
        return response()->json($task);
    }

public function update(Request $request, $id)
{
    // Validate the request data
    $validated = $request->validate([
           'user_id' => 'nullable|exists:users,id',
        'category_id' => 'nullable|exists:categories,id',
        'customer_name' => 'nullable|string|max:255',
        'city_name' => 'nullable|string|max:255',
        'address' => 'nullable|string',
        'landmark' => 'nullable|string',
        'pincode' => 'nullable|string',
        'village_ward_no' => 'nullable|string',
        'mobile_number' => 'nullable|string|max:15',
    ]);

    // Find the task by ID
    $task = CategoryTasks::find($id);

    // Check if task exists
    if (!$task) {
        return response()->json(['message' => 'Task not found'], 404);
    }

    // Prepare the data for updating, only if the field is not null
    $updateData = [];
    if ($validated['user_id'] !== null) {
        $updateData['user_id'] = $validated['user_id'];
    }
    if ($validated['category_id'] !== null) {
        $updateData['category_id'] = $validated['category_id'];
    }
    if ($validated['customer_name'] !== null) {
        $updateData['customer_name'] = $validated['customer_name'];
    }
    if ($validated['city_name'] !== null) {
        $updateData['city_name'] = $validated['city_name'];
    }
    if ($validated['address'] !== null) {
        $updateData['address'] = $validated['address'];
    }
    if ($validated['landmark'] !== null) {
        $updateData['landmark'] = $validated['landmark'];
    }
    if ($validated['pincode'] !== null) {
        $updateData['pincode'] = $validated['pincode'];
    }
    if ($validated['village_ward_no'] !== null) {
        $updateData['village_ward_no'] = $validated['village_ward_no'];
    }
    if ($validated['mobile_number'] !== null) {
        $updateData['mobile_number'] = $validated['mobile_number'];
    }

    // Update the task data with only the fields that are not null
    $task->update($updateData);
 $task->makeHidden(['created_at', 'updated_at']);
    // Return the updated task data in JSON format
    return response()->json([
        'status' => 200,
        'message' => 'Task updated successfully.',
        'data' => $task,
    ], 200);
}



    // Delete a task
    public function destroy(Request $request)
    {
        $validated = $request->validate([
        'id' => 'required|integer|exists:tasks,id', // Ensure the task ID exists
    ]);
        // Find the task by ID
        $task = CategoryTasks::find($validated['id']);

        // Check if task exists
        if (!$task) {
            
             // Return a success response
    return response()->json([
        'status' => 404,
        'message' => 'Task not found.',
    ], 200);
        }

        // Delete the task
        $task->delete();

         // Return a success response
    return response()->json([
        'status' => 200,
        'message' => 'Task deleted successfully.',
    ], 200);
    }
}
