<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use App\Models\Role;
use Illuminate\Support\Facades\DB;

class ClientController extends Controller
{
    public function index()
    {
        $users = DB::table('users')
            ->join('roles', 'users.role_id', '=', 'roles.id')
            ->select('users.*', 'roles.name as role_name')
            ->where('users.role_id','=','4')   
            ->get(); // Fetch users with roles
        return view('admin.clients.index', compact('users'));
    }

    public function create()
    {
    
        return view('admin.clients.create');  // Pass roles to the create view
    }


    // Other methods...

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:users,email',
            'role_id' => 'required',
            'status' => 'required|in:0,1',
            'phone_number' => 'nullable|string',
        ]);

        User::create($request->all());

        return redirect()->route('clients.index')->with('success', 'Client created successfully!');
    }



  // Show the edit form
  public function edit($id)
  {
      // Find the user by id
      $user = User::findOrFail($id);
      


      // Return the edit view with user and roles data
      return view('admin.clients.edit', compact('user'));
  }

  public function update(Request $request, $id)
  {
      // Validate the form data
      $validated = $request->validate([
          'name' => 'required|string|max:255',
          'last_name' => 'required|string|max:255',
          'email' => 'required|email|max:255|unique:users,email,' . $id,
          'status' => 'required|boolean',
          'phone_number' => 'nullable|string|max:20',
      ]);

      // Find the user by id
      $user = User::findOrFail($id);

      // Update the user's information
      $user->update($validated);

      // Redirect with a success message
      return redirect()->route('clients.index')->with('success', 'User updated successfully!');
  }
}
