<?php
namespace App\Http\Controllers;

use App\Models\Setting;
use Illuminate\Http\Request;

class SettingsController extends Controller
{
    public function edit()
{
    // Fetch current settings from the database, or create a new instance if no settings exist
    $setting = Setting::first();

    if (!$setting) {
        // If no settings exist, create a default one or return with an error message
        $setting = new Setting(); // This will give you an empty instance, but you can also create defaults if needed
    }
    if ($setting->logo) {
        $setting->logo = 'https://elecorepair.site/storage/app/public/' . $setting->logo;
    }
    if ($setting->qr_image) {
        $setting->qr_image = 'https://elecorepair.site/storage/app/public/' . $setting->qr_image;
    }
  

    return view('settings.edit', compact('setting'));
}


public function update(Request $request)
{
    // Validate the request data
    $request->validate([
        'logo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        'qr_image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Add QR image validation
        'contact_number' => 'nullable|string|max:15',
        'address' => 'nullable|string|max:255',
        'email' => 'nullable|email|max:255',
    ]);

    // Retrieve the first settings record, or create a new one if none exist
    $setting = Setting::first();

    if (!$setting) {
        $setting = new Setting();
    }

    // Handle logo upload
    if ($request->hasFile('logo')) {
        $logoPath = $request->file('logo')->store('logos', 'public');
        $setting->logo = $logoPath;
    }

    // Handle QR image upload
    if ($request->hasFile('qr_image')) {
        $qrImagePath = $request->file('qr_image')->store('qr_images', 'public');
        $setting->qr_image = $qrImagePath;
    }

    // Update other fields
    $setting->contact_number = $request->contact_number;
    $setting->address = $request->address;
    $setting->email = $request->email;

    // Save the updated settings
    $setting->save();

    return redirect()->route('settings.edit')->with('success', 'Settings updated successfully!');
}


}
