<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use App\Models\Role;
use Illuminate\Support\Facades\DB;

class UserController extends Controller
{

    public function show($id)
    {
        $user = User::findOrFail($id);

        return view('admin.users.show', compact('user'));
    }



public function index()
{
    $users = DB::table('users')
        ->join('roles', 'users.role_id', '=', 'roles.id')
        ->select('users.*', 'roles.name as role_name')  // Select role_name as role_name
        ->where('users.role_id', '!=', 1) // Corrected where clause
        ->get(); // Fetch users with roles

    return view('admin.users.index', compact('users'));
}



    public function supervisors()
{
    $users = DB::table('users')
        ->join('roles', 'users.role_id', '=', 'roles.id')
        ->where('role_id', 2)
        ->select('users.*', 'roles.name as role_name')
        ->get();

    return view('admin.users.supervisors', compact('users'));
}

public function seniorSupervisors()
{
    $users = DB::table('users')
        ->join('roles', 'users.role_id', '=', 'roles.id')
        ->where('role_id', 3)
        ->select('users.*', 'roles.name as role_name')
        ->get();

    return view('admin.users.senior-supervisors', compact('users'));
}

public function clients()
{
    $users = DB::table('users')
        ->join('roles', 'users.role_id', '=', 'roles.id')
        ->where('role_id', 4)
        ->select('users.*', 'roles.name as role_name')
        ->get();

    return view('admin.users.clients', compact('users'));
}

public function workers()
{
    $users = DB::table('users')
        ->join('roles', 'users.role_id', '=', 'roles.id')
        ->whereNotIn('role_id', [1,2, 3, 4])
        ->select('users.*', 'roles.name as role_name')
        ->get();

    return view('admin.users.workers', compact('users'));
}


    public function create()
    {
        $roles = Role::all();  // Fetch all roles for the user selection
        return view('admin.users.create', compact('roles'));  // Pass roles to the create view
    }

    public function seniorsupervisor_create(){
        $role_id = 3;
        $title = "Senior Supervisor";
        return view('admin.users.otheruser_create', compact('role_id','title')); 
    }

    public function supervisor_create(){
        $role_id = 2;
        $title = "Supervisor";
        return view('admin.users.otheruser_create', compact('role_id','title')); 
    }

    public function client_create(){
        $role_id = 4;
        $title = "Client";
        return view('admin.users.otheruser_create', compact('role_id','title')); 
    }

    public function worker_create()
    {
        $roles = Role::whereNotIn('id', [1, 2, 3, 4])->get(); // Fetch roles where role_id is not 1, 2, 3, or 4
        return view('admin.users.worker_create', compact('roles')); // Pass roles to the view
    }
    

    // Other methods...

    public function store(Request $request)
    {
        // Validate the request data
        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'role_id' => 'required',
            'status' => 'required|in:0,1',
            'phone_number' => 'nullable|string',
            'password' => 'required|string|min:8|confirmed', // Validation for password
        ]);
        
        // Create the user and hash the password before storing
        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'role_id' => $request->role_id,
            'status' => $request->status,
            'phone_number' => $request->phone_number,
            'password' => bcrypt($request->password), // Hash the password
        ]);
    

            return redirect()->route('users.index')->with('success', 'User created successfully!');
        
    }
    
    


  // Show the edit form
  public function edit($id)
  {
      // Find the user by id
      $user = User::findOrFail($id);
      
      // Fetch all roles
      $roles = Role::all();

      // Return the edit view with user and roles data
      return view('admin.users.edit', compact('user', 'roles'));
  }

  public function update(Request $request, $id)
  {
      // Validate the form data
      $validated = $request->validate([
          'name' => 'required|string|max:255',
          'email' => 'required|email|max:255|unique:users,email,' . $id,
          'role_id' => 'required|exists:roles,id',
          'status' => 'required|boolean',
          'phone_number' => 'nullable|string|max:20',
      ]);

      // Find the user by id
      $user = User::findOrFail($id);

      // Update the user's information
      $user->update($validated);

      // Redirect with a success message
      return redirect()->route('users.index')->with('success', 'User updated successfully!');
  }
  
    
 public function destroy($id)
{
    // Find the user by ID
    $user = User::findOrFail($id);

    // Store the role_id before deleting
    $roleId = $user->role_id;

    // Delete the user
    $user->delete();

            return redirect()->route('users.index')->with('success', 'User deleted successfully!');
    }

}
