@extends('adminlte::page')

@section('title', 'Edit Project')

@section('content_header')
    <h1>Edit Project</h1>
@stop

@section('content')
    <form action="{{ route('projects.update', $project->id) }}" method="POST">
        @csrf
        @method('PUT') <!-- Use PUT for updating the resource -->

        <div class="form-group">
            <label for="name">Project Name</label>
            <input type="text" name="name" id="name" class="form-control" value="{{ old('name', $project->name) }}" required>
        </div>

        <div class="form-group">
            <label for="code">Project Code</label>
            <input type="text" name="code" id="code" class="form-control" value="{{ old('code', $project->code) }}" required>
        </div>
        
        <div class="form-group">
            <label for="address">Address</label>
            <textarea name="address" id="address" class="form-control" required>{{ old('address', $project->address) }}</textarea>
        </div>

        <div class="form-group">
            <label for="description">Description</label>
            <textarea name="description" id="description" class="form-control" required>{{ old('description', $project->description) }}</textarea>
        </div>

        <div class="form-group">
            <label for="status">Status</label>
            <select name="status" id="status" class="form-control" required>
                <option value="ongoing" {{ old('status', $project->status) == 'ongoing' ? 'selected' : '' }}>Ongoing</option>
                <option value="completed" {{ old('status', $project->status) == 'completed' ? 'selected' : '' }}>Completed</option>
                <option value="pending" {{ old('status', $project->status) == 'pending' ? 'selected' : '' }}>Pending</option>
            </select>
        </div>

      <div class="form-group">
    <label for="assign_supervisor">Assign Supervisor</label>
    <select name="assign_supervisor[]" id="assign_supervisor" class="form-control select2" multiple>
        @foreach($assignSupervisors as $supervisor)
            <option value="{{ $supervisor->id }}"
                {{ is_array($project->assign_supervisor) && in_array($supervisor->id, $project->assign_supervisor) 
                    || (is_string($project->assign_supervisor) && in_array($supervisor->id, json_decode($project->assign_supervisor ?? '[]', true))) ? 'selected' : '' }}>
                {{ $supervisor->name }} {{ $supervisor->last_name }}
            </option>
        @endforeach
    </select>
</div>


<div class="form-group">
    <label for="assign_senior_supervisor">Assign Senior Supervisor</label>
    <select name="assign_senior_supervisor[]" id="assign_senior_supervisor" multiple class="form-control select2">
        @foreach($assignSeniorSupervisors as $senior)
            <option value="{{ $senior->id }}"
                {{ (is_array($project->assign_senior_supervisor) && in_array($senior->id, $project->assign_senior_supervisor)) 
                    || (is_string($project->assign_senior_supervisor) && in_array($senior->id, json_decode($project->assign_senior_supervisor ?? '[]', true))) ? 'selected' : '' }}>
                {{ $senior->name }} {{ $senior->last_name }}
            </option>
        @endforeach
    </select>
</div>

<div class="form-group">
    <label for="assign_clients">Assign Client</label>
    <select name="assign_clients[]" id="assign_clients" class="form-control select2" multiple>
        <option value="">Select Client</option>
        @foreach($assignClients as $client)
            <option value="{{ $client->id }}"
                {{ (is_array($project->assign_clients) && in_array($client->id, $project->assign_clients)) 
                    || (is_string($project->assign_clients) && in_array($client->id, json_decode($project->assign_clients ?? '[]', true))) ? 'selected' : '' }}>
                {{ $client->name }} {{ $client->last_name }}
            </option>
        @endforeach
    </select>
</div>

<div class="form-group">
    <label for="assign_worker">Assign Worker</label>
    <select name="assign_worker[]" id="assign_worker" class="form-control select2" multiple>
        @foreach($assignWorkers as $worker)
            <option value="{{ $worker->id }}"
                {{ (is_array($project->assign_workers) && in_array($worker->id, $project->assign_workers)) 
                    || (is_string($project->assign_workers) && in_array($worker->id, json_decode($project->assign_workers ?? '[]', true))) ? 'selected' : '' }}>
                {{ $worker->name }} {{ $worker->last_name }}
            </option>
        @endforeach
    </select>
</div>



        <button type="submit" class="btn btn-primary">Update Project</button>
    </form>
@stop

@section('css')
    <link href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/css/select2.min.css" rel="stylesheet">
    <style>
        /* Change the color of selected options in select2 */
        .select2-container .select2-selection--multiple .select2-selection__choice {
            color: #000 !important; /* Apply black color to the selected option text */
        }
        .select2-container .select2-selection--multiple .select2-selection__choice__remove {
            color: #000 !important; /* Change the remove button color to black too */
        }
    </style>
    @stop

@section('js')
    <script src="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/js/select2.min.js"></script>
    <script>
        $(document).ready(function() {
            $('.select2').select2(); // Initialize select2 for multiple selects
        });
    </script>
@stop
