<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ProjectController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ClientController;
use App\Http\Controllers\SettingsController;
use App\Http\Controllers\FileController;
use App\Http\Controllers\TasksController;

use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\TaskController;

use App\Http\Controllers\DashboardController;

use App\Http\Controllers\Auth\ForgotPasswordController;
use App\Http\Controllers\Auth\ResetPasswordController;




/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});

Auth::routes();
Route::get('password/reset', [ForgotPasswordController::class, 'showLinkRequestForm'])->name('password.request');
Route::post('password/email', [ForgotPasswordController::class, 'sendResetLinkEmail'])->name('password.email');
Route::get('password/reset/{token}', [ResetPasswordController::class, 'showResetForm'])->name('password.reset');
Route::post('password/reset', [ResetPasswordController::class, 'reset'])->name('password.update');

Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
Route::middleware(['auth'])->group(function () {
Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');


Route::get('/profile', function () {
    return view('profile');
})->middleware(['auth'])->name('profile');



Route::prefix('admin')->name('admin.')->group(function () {
    Route::resource('categories', CategoryController::class);
});
Route::prefix('admin')->name('admin.')->group(function () {
    Route::resource('tasks', TaskController::class);  // Resource routes

    // Custom route for viewing a task
    Route::get('tasks/view/{id}', [TaskController::class, 'view'])->name('tasks.view');
});


Route::resource('projects', ProjectController::class);
// web.php (routes file)
Route::get('projects/{project}/edit', [ProjectController::class, 'edit'])->name('projects.edit');
Route::put('projects/{project}', [ProjectController::class, 'update'])->name('projects.update');

Route::resource('tasks', TasksController::class);
Route::get('tasks/{task}', [TasksController::class, 'show'])->name('tasks.show');

Route::get('/task_images/{filename}', [FileController::class, 'show']);



Route::resource('roles', RoleController::class); 

// Custom Routes for User Lists
Route::get('/users/supervisors', [UserController::class, 'supervisors'])->name('users.supervisors');
Route::get('/users/senior-supervisors', [UserController::class, 'seniorSupervisors'])->name('users.senior-supervisors');
Route::get('/users/clients', [UserController::class, 'clients'])->name('users.clients');
Route::get('/users/workers', [UserController::class, 'workers'])->name('users.workers');

Route::get('/users/workers/create', [UserController::class, 'worker_create'])->name('users.workers.create');
Route::get('/users/senior-supervisors/create', [UserController::class, 'seniorsupervisor_create'])->name('users.senior-supervisors.create');
Route::get('/users/supervisors/create', [UserController::class, 'supervisor_create'])->name('users.supervisors.create');
Route::get('/users/clients/create', [UserController::class, 'client_create'])->name('users.clients.create');

// Resource Routes
Route::resource('users', UserController::class)->except(['show']);
Route::get('/users/{user}/edit', [UserController::class, 'edit'])->name('users.edit');
Route::put('/users/{user}', [UserController::class, 'update'])->name('users.update');



Route::post('/logout', [App\Http\Controllers\Auth\LoginController::class, 'logout'])->name('logout');

Route::get('/settings/edit', [SettingsController::class, 'edit'])->name('settings.edit');
Route::put('/settings/update', [SettingsController::class, 'update'])->name('settings.update');
});

Route::get('/admin/settings', function () {
    return view('admin.settings');  // Create a view at resources/views/admin/settings.blade.php
})->middleware('auth');  // Protect it with authentication middleware

